@@ -42,10 +42,15 @@ TMPLPRO_API int APICALL tmplpro_push_option_param_map(struct tmplpro_param *para
 
 TMPLPRO_API int APICALL tmplpro_get_int_option(struct tmplpro_param* param, const char *p, int* failure_ptr);
 TMPLPRO_API int APICALL tmplpro_set_int_option(struct tmplpro_param* param, const char *p, int value);
+TMPLPRO_API void APICALL tmplpro_reset_int_options(struct tmplpro_param* param);
 
 TMPLPRO_API int APICALL tmplpro_errno(struct tmplpro_param* param);
 TMPLPRO_API const char* APICALL tmplpro_errmsg(struct tmplpro_param* param);
 
+TMPLPRO_API int APICALL tmplpro_set_log_file(struct tmplpro_param* param, const char* logfilename);
+TMPLPRO_API size_t APICALL tmplpro_param_allocated_memory_info(struct tmplpro_param* param);
+
+
 
 struct exprval;
 TMPLPRO_API void APICALL tmplpro_set_expr_as_int64 (ABSTRACT_EXPRVAL*,EXPR_int64);
@@ -192,6 +197,10 @@ TMPLPRO_API PSTRING APICALL tmplpro_get_expr_as_pstring (ABSTRACT_EXPRVAL*);
     Non-null exit code indicates failure (invalid option or invalid option value).
 */
 
+/*! \fn void  tmplpro_reset_int_options(struct tmplpro_param* param);
+    \brief reset integer userspace options to their default values.
+*/
+
 /*! \fn int  tmplpro_errno(struct tmplpro_param* param);
     \brief exit code of the last function call.
 
